@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 # -.- coding: utf-8 -.-
 
 # remote-test.py
@@ -36,11 +36,12 @@ import pickle
 from subprocess import Popen, PIPE
 
 # DBus setup
-import gobject
+import gi
 from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
 from dbus.exceptions import DBusException
 
+from gi.repository import GLib
 from zeitgeist.datamodel import (Event, Subject, Interpretation, Manifestation,
 	TimeRange, StorageState, DataSource, NULL_EVENT, ResultType)
 
@@ -71,7 +72,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(2, len(result))
+		self.assertEqual(2, len(result))
 		
 	def testMonitorInsertEventsWithSubjectTemplate(self):
 		result = []
@@ -95,7 +96,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(1, len(result))
+		self.assertEqual(1, len(result))
 		
 	def testMonitorInsertEventsOutOfTimeRange(self):
 		result = []
@@ -119,7 +120,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(3, len(result))
+		self.assertEqual(3, len(result))
 	
 	def testMonitorInsertEventsWithWildcardSubjectTemplate(self):
 		result = []
@@ -143,7 +144,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(2, len(result))
+		self.assertEqual(2, len(result))
 	
 	def testMonitorInsertEventsWithNegatedSubjectTemplate(self):
 		result = []
@@ -167,7 +168,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(4, len(result))
+		self.assertEqual(4, len(result))
 	
 	def testMonitorDeleteEvents(self):
 		result = []
@@ -176,7 +177,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		
 		@asyncTestMethod(mainloop)
 		def notify_insert_handler(time_range, events):
-			event_ids = map(lambda ev : ev.id, events)
+			event_ids = [ev.id for ev in events]
 			self.client.delete_events(event_ids)
 		
 		@asyncTestMethod(mainloop)
@@ -190,7 +191,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(2, len(result))
+		self.assertEqual(2, len(result))
 	
 	def testMonitorDeleteNonExistingEvent(self):
 		result = []
@@ -206,7 +207,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 
 		@asyncTestMethod(mainloop)
 		def notify_insert_handler(time_range, events):
-			event_ids = map(lambda ev : ev.id, events)
+			event_ids = [ev.id for ev in events]
 			self.client.delete_events([9999999])
 		
 		@asyncTestMethod(mainloop)
@@ -217,7 +218,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.install_monitor(TimeRange(125, 145), [],
 			notify_insert_handler, notify_delete_handler)
 		
-		gobject.timeout_add_seconds(5, timeout)
+		GLib.timeout_add_seconds(5, timeout)
 		self.client.insert_events(events)
 		mainloop.run()
 	
@@ -234,7 +235,7 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 
 		@asyncTestMethod(mainloop)
 		def notify_insert_handler1(time_range, events):
-			event_ids = map(lambda ev : ev.id, events)
+			event_ids = [ev.id for ev in events]
 			self.client.delete_events(event_ids)
 		
 		@asyncTestMethod(mainloop)
@@ -256,8 +257,8 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.client.insert_events(events)
 		mainloop.run()
 		
-		self.assertEquals(2, len(result1))
-		self.assertEquals(2, len(result2))
+		self.assertEqual(2, len(result1))
+		self.assertEqual(2, len(result2))
 
 	def testMonitorInstallRemoval(self):
 		result = []
@@ -283,8 +284,8 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		
 		self.client.remove_monitor(mon, removed_handler)
 		mainloop.run()
-		self.assertEquals(1, len(result))
-		self.assertEquals(1, result.pop())
+		self.assertEqual(1, len(result))
+		self.assertEqual(1, result.pop())
 
 	def testMonitorReconnection(self):
 		result = []
@@ -309,11 +310,11 @@ class ZeitgeistMonitorTest(testutils.RemoteTestCase):
 		self.spawn_daemon()
 
 		# Insert events in idle loop to give the reconnection logic enough time
-		gobject.idle_add(lambda *args: self.client.insert_events(events))
+		GLib.idle_add(lambda *args: self.client.insert_events(events))
 
 		mainloop.run()
 		
-		self.assertEquals(3, len(result))
+		self.assertEqual(3, len(result))
 
 if __name__ == "__main__":
 	unittest.main()
